# Generated by Django 2.1.11 on 2019-10-21 09:58

from django.db import migrations
import django.db.models.manager


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0015_auto_20191001_0847'),
    ]

    operations = [
        migrations.AlterModelManagers(
            name='displaycolor',
            managers=[
                ('available_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.AlterModelManagers(
            name='issuetype',
            managers=[
                ('available_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.AlterModelManagers(
            name='projectstatus',
            managers=[
                ('available_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.AlterModelManagers(
            name='projecttype',
            managers=[
                ('available_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.AlterModelManagers(
            name='queue',
            managers=[
                ('available_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.AlterModelManagers(
            name='source',
            managers=[
                ('available_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.AlterModelManagers(
            name='subissuetype',
            managers=[
                ('available_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.AlterModelManagers(
            name='ticketpriority',
            managers=[
                ('available_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.AlterModelManagers(
            name='ticketstatus',
            managers=[
                ('available_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.AlterModelManagers(
            name='tickettype',
            managers=[
                ('available_objects', django.db.models.manager.Manager()),
            ],
        ),
    ]



# Generated by Django 3.1.7 on 2021-11-24 18:08

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0098_auto_20211029_1641'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='contract',
            options={'ordering': ('name',)},
        ),
        migrations.AlterField(
            model_name='contract',
            name='name',
            field=models.CharField(db_index=True, max_length=250),
        ),
    ]



# Generated by Django 2.1.14 on 2020-03-13 16:43

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0050_remove_ticket_role'),
    ]

    operations = [
        migrations.CreateModel(
            name='Contract',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=250)),
                ('number', models.CharField(blank=True, max_length=50, null=True)),
                ('account', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='djautotask.Account')),
            ],
        ),
    ]



# Generated by Django 2.1.14 on 2020-01-30 12:18

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0037_subissuetype_parent_value'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='timeentry',
            options={'ordering': ('-start_date_time', 'id'), 'verbose_name_plural': 'Time entries'},
        ),
    ]



# Generated by Django 4.2.11 on 2024-06-17 11:37

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0116_alter_servicecall_tasks_alter_servicecall_tickets'),
    ]

    operations = [
        migrations.AlterField(
            model_name='tasknote',
            name='task',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='notes', to='djautotask.task'),
        ),
        migrations.AlterField(
            model_name='ticketnote',
            name='ticket',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='notes', to='djautotask.ticket'),
        ),
    ]



# Generated by Django 2.1.14 on 2020-05-19 11:00

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0066_auto_20200512_1420'),
    ]

    operations = [
        migrations.AddField(
            model_name='ticket',
            name='service_level_agreement',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='ticket',
            name='service_level_agreement_has_been_met',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='ticket',
            name='service_level_agreement_paused_next_event_hours',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=9, null=True),
        ),
    ]



# Generated by Django 2.1.14 on 2020-02-05 16:51

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0043_department'),
        ('djautotask', '0043_timeentry_allocation_code'),
    ]

    operations = [
    ]



# Generated by Django 3.1.4 on 2021-01-13 17:43

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0087_auto_20210108_1307'),
        ('djautotask', '0087_auto_20210108_1214'),
    ]

    operations = [
    ]



# Generated by Django 4.0.10 on 2023-06-22 12:11

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0114_tasktype_tasktypetracker'),
    ]

    operations = [
        migrations.AddField(
            model_name='task',
            name='task_type',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='djautotask.tasktype'),
        ),
    ]



# Generated by Django 2.1.11 on 2019-09-13 09:41

from django.db import migrations, models
import django.db.models.deletion
import django_extensions.db.fields


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0002_ticket_ticket_number'),
    ]

    operations = [
        migrations.CreateModel(
            name='TicketStatus',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', django_extensions.db.fields.CreationDateTimeField(auto_now_add=True, verbose_name='created')),
                ('modified', django_extensions.db.fields.ModificationDateTimeField(auto_now=True, verbose_name='modified')),
                ('value', models.CharField(blank=True, max_length=50, null=True)),
                ('label', models.CharField(blank=True, max_length=50, null=True)),
                ('is_default_value', models.BooleanField(default=False)),
                ('sort_order', models.PositiveSmallIntegerField(blank=True, null=True)),
                ('parent_value', models.CharField(blank=True, max_length=20, null=True)),
                ('is_active', models.BooleanField(default=False)),
                ('is_system', models.BooleanField(default=False)),
            ],
            options={
                'verbose_name': 'Ticket status',
                'verbose_name_plural': 'Ticket statuses',
            },
        ),
        migrations.AddField(
            model_name='ticket',
            name='status',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='djautotask.TicketStatus'),
        ),
    ]



# Generated by Django 3.1.7 on 2021-06-29 11:24

from django.db import migrations


def process_tasks(apps, schema_editor):
    Task = apps.get_model('djautotask', 'Task')

    # Remove tasks without a project in preparation for migration
    # removing null=True from project foreign key on Task model.
    null_project_tasks = Task.objects.filter(project__isnull=True)
    for task in null_project_tasks:
        task.delete()


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0091_auto_20210525_1723'),
    ]

    operations = [
        migrations.RunPython(process_tasks)
    ]



# Generated by Django 2.1.14 on 2020-02-05 14:55

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0041_merge_20200204_1546'),
    ]

    operations = [
        migrations.CreateModel(
            name='Role',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=200)),
                ('active', models.BooleanField(default=True)),
                ('description', models.CharField(blank=True, max_length=200, null=True)),
                ('hourly_factor', models.DecimalField(blank=True, decimal_places=2, max_digits=9, null=True)),
                ('hourly_rate', models.DecimalField(blank=True, decimal_places=2, max_digits=9, null=True)),
                ('role_type', models.PositiveIntegerField(blank=True, null=True)),
                ('system_role', models.BooleanField(default=False)),
            ],
        ),
        migrations.AddField(
            model_name='timeentry',
            name='role',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='djautotask.Role'),
        ),
    ]
